#! /bin/bash

# Where am I
dir=`pwd`
dir=$dir
export dir

MACHINE=`uname -m`
export MACHINE

sortfonts () {
	cd $dir/original-message-file
	ls -1 *.fnt > /tmp/list1
	grep ".fnt" $dir/original-message-file/gfxboot.cfg | awk -F'=' '{print $NF}' | sort > /tmp/list2
	comm -23 /tmp/list1 /tmp/list2 > /tmp/list3

	for i in `cat /tmp/list3` ; do
	mv $dir/original-message-file/$i $dir/fonts/fnt/$i
	done;
	sleep 0.5
}
export -f sortfonts

unpack () {
	cd $dir/original-message-file
	ls -1  >  /tmp/name
	NAME=`cat /tmp/name`
	cpio -ivu < $NAME
	mv $NAME $dir/$NAME
}
export -f unpack

repack () {
	rm -f $dir/test-iso/boot/grub/message
	cd $dir/original-message-file
	sortfonts
	ls > /tmp/filelist && cpio -o < /tmp/filelist > message
	cp message $dir/test-iso/boot/grub/message
	mv message $dir/new-message-file/message
	rm -f message
	cd $dir
	mkisofs -R -b boot/grub/stage2_eltorito -no-emul-boot -boot-load-size 4 -boot-info-table -o splashy.iso test-iso
}
export -f repack

convertfnt () {
	TTF_FONT_NOSPACES=`echo "${TTF_FONT%.*}"|sed 's/ /-/g'`
	cd $dir/fonts/fnt
	if [ "$MACHINE" = "x86_64" ]; then
	   gfxboot-font64 -c ISO-8859-15 -f "${TTF_FONT%.*}":size=$FNTSIZE "$TTF_FONT_NOSPACES"-$FNTSIZE.fnt
	else
	   gfxboot-font32 -c ISO-8859-15 -f "${TTF_FONT%.*}":size=$FNTSIZE "$TTF_FONT_NOSPACES"-$FNTSIZE.fnt
	fi
}
export -f convertfnt

### Select Image ##############################################################
Select-Image () {
	rox -d $dir/original-message-file
	Xdialog --title "Select Image" --msgbox "Copy your Image into the directory
 that just opened and click OK. 
 The image must be the same size as the 
 original and be named back.jpg" 0 0 
	rox -D $dir/original-message-file
}
export -f Select-Image

if [ ! -f "$dir/original-message-file/gfxboot.cfg" ]; then
rox -d $dir/original-message-file &
Xdialog --title "Message Editor" --msgbox " Copy your boot-splash message file
 in the window that just opened and click OK." 0 0 
rox -D $dir/original-message-file
unpack
cd $dir
fi

export GFXBOOT=$dir/original-message-file/gfxboot.cfg

# Create "normal" variables out of gfxboot.cfg's contents
CNT=0
RES=( 1024x768 800x600 640x480 )

oIFS=$IFS; IFS=''
while read -r LINE; do
  NAME="`echo $LINE | cut -f1 -d '='`"
  VALUE="`echo $LINE | cut -f2 -d '='`"

  case "$NAME" in
    layout) 							LAYOUT="$VALUE" ;;
	menu.transparency)					MENU_TRANSPARENCY="$VALUE" ;;
	font.normal)						FONT_NORMAL="$VALUE" ;;
	font.large)							FONT_LARGE="$VALUE" ;;
	background)							BACKGROUND="$VALUE" ;;
	mainmenu.entries)					MAINMENU_ENTRIES="$VALUE" ;;
	mainmenu.bar.minwidth)				MAINMENU_BAR_MINWIDTH="$VALUE" ;;
	mainmenu.bar.transparency)			MAINMENU_BAR_TRANSPARENCY="$VALUE" ;;
	mainmenu.bar.color)					MAINMENU_BAR_COLOR="#${VALUE#*x}" ;;
	mainmenu.normal.fg)					MAINMENU_NORMAL_FG="#${VALUE#*x}" ;;
	mainmenu.selected.fg)				MAINMENU_SELECTED_FG="#${VALUE#*x}" ;;
	bootopt.label.fg)					BOOTOPT_LABEL_FG="#${VALUE#*x}" ;;
	bootopt.text.fg)					BOOTOPT_TEXT_FG="#${VALUE#*x}" ;;
	menu.normal.bg)						MENU_NORMAL_BG="#${VALUE#*x}" ;;
	menu.normal.fg)						MENU_NORMAL_FG="#${VALUE#*x}" ;;
	menu.selected.bg)					MENU_SELECTED_BG="#${VALUE#*x}" ;;
	menu.selected.fg)					MENU_SELECTED_FG="#${VALUE#*x}" ;;
	window.bg)							WINDOW_BG="#${VALUE#*x}" ;;
	window.fg)							WINDOW_FG="#${VALUE#*x}" ;;
	window.title.bg)					WINDOW_TITLE_BG="#${VALUE#*x}" ;;
	window.title.fg)					WINDOW_TITLE_FG="#${VALUE#*x}" ;;
	window.title.error.bg)				WINDOW_TITLE_ERROR_BG="#${VALUE#*x}" ;;
	help.link.fg)						HELP_LINK_FG="#${VALUE#*x}" ;;
	help.link.selected.fg)				HELP_LINK_SELECTED_FG="#${VALUE#*x}" ;;
	help.link.selected.bg)				HELP_LINK_SELECTED_BG="#${VALUE#*x}" ;;
	help.highlight.fg)					HELP_HIGHTLIGHT_FG="#${VALUE#*x}" ;;
	panel.normal.fg)					PANEL_NORMAL_FG="#${VALUE#*x}" ;;
	panel.title.fg)						PANEL_TITLE_FG="#${VALUE#*x}" ;;
	panel.f-key.fg)						PANEL_F_KEY_FG="#${VALUE#*x}" ;;
	screen.size)						eval SCREEN_SIZE_${RES[$CNT]}="$VALUE" ;;
	mainmenu.pos)						eval MAINMENU_POS_${RES[$CNT]}="$VALUE" ;;
	bootopt.pos)						eval BOOTOPT_POS_${RES[$CNT]}="$VALUE" && ((CNT++));;
  esac
done <<< `grep '=' "$GFXBOOT" | grep -vE ';|^\['`
IFS=$oIFS

# For some of variables we need to use temporari files, since they'll be modified in sub-windows
export TEMPFILE=/tmp/tempfile_$$
echo "$SCREEN_SIZE_1024x768" > $TEMPFILE
echo "$MAINMENU_POS_1024x768" >> $TEMPFILE
echo "$BOOTOPT_POS_1024x768" >> $TEMPFILE

echo "$SCREEN_SIZE_800x600" >> $TEMPFILE
echo "$MAINMENU_POS_800x600" >> $TEMPFILE
echo "$BOOTOPT_POS_800x600" >> $TEMPFILE

echo "$SCREEN_SIZE_640x480" >> $TEMPFILE
echo "$MAINMENU_POS_640x480" >> $TEMPFILE
echo "$BOOTOPT_POS_640x480" >> $TEMPFILE

# =============================================================================

# Ok, this function must be complemented
save_settings () {
CONFIG="${GFXBOOT}.new"
  : > $CONFIG

  # Ok, saving settings
  echo -e "[base]" >> $CONFIG
  echo "layout=$varLAYOUT" >> $CONFIG
echo "; default font" >> $CONFIG  
  echo "font.normal=$varFONT_NORMAL" >> $CONFIG
echo "; main menu font" >> $CONFIG  
  echo "font.large=$varFONT_LARGE" >> $CONFIG
echo "; background image" >> $CONFIG  
  echo "background=back.jpg" >> $CONFIG
echo "; max. visible main menu items" >> $CONFIG  
  echo "mainmenu.entries=$varMAINMENU_ENTRIES" >> $CONFIG
echo "; main menu selection bar minimal width" >> $CONFIG
  echo "mainmenu.bar.minwidth=$varMAINMENU_BAR_MINWIDTH" >> $CONFIG
echo "; main menu selection bar transparency (0..255)" >> $CONFIG
  echo "mainmenu.bar.transparency=$varMAINMENU_BAR_TRANSPARENCY" >> $CONFIG
echo "; main menu colors" >> $CONFIG
  echo "mainmenu.bar.color=0x${varMAINMENU_BAR_COLOR#*#}" >> $CONFIG
  echo "mainmenu.normal.fg=0x${varMAINMENU_NORMAL_FG#*#}" >> $CONFIG
  echo "mainmenu.selected.fg=0x${varMAINMENU_SELECTED_FG#*#}" >> $CONFIG
echo "; boot option colors" >> $CONFIG
  echo "bootopt.label.fg=0x${varBOOTOPT_LABEL_FG#*#}" >> $CONFIG
  echo "bootopt.text.fg=0x${varBOOTOPT_TEXT_FG#*#}" >> $CONFIG
echo "; help window colors" >> $CONFIG
  echo "window.fg=0x${varWINDOW_FG#*#}" >> $CONFIG
  echo "window.bg=0x${varWINDOW_BG#*#}" >> $CONFIG
  echo "window.title.bg=0x${varWINDOW_TITLE_BG#*#}" >> $CONFIG
  echo "window.title.fg=0x${varWINDOW_TITLE_FG#*#}" >> $CONFIG
  echo "window.title.error.bg=0x${varWINDOW_TITLE_ERROR_BG#*#}" >> $CONFIG
echo "; help system colors" >> $CONFIG
  echo "help.link.fg=0x${varHELP_LINK_FG#*#}" >> $CONFIG
  echo "help.link.selected.fg=0x${varHELP_LINK_SELECTED_FG#*#}" >> $CONFIG
  echo "help.link.selected.bg=0x${varHELP_LINK_SELECTED_BG#*#}" >> $CONFIG
  echo "help.highlight.fg=0x${varHELP_HIGHTLIGHT_FG#*#}" >> $CONFIG
echo "; panel colors" >> $CONFIG
  echo "panel.normal.fg=0x${varPANEL_NORMAL_FG#*#}" >> $CONFIG
  echo "panel.f-key.fg=0x${varPANEL_F_KEY_FG#*#}" >> $CONFIG
  
  # put rest of options here, when you'll be done with all widgets
  
  echo -e "\n[1024x768]" >> $CONFIG
  # we need to extract these variables from temporary file
  echo "screen.size=$(sed "1q;d" $TEMPFILE)" >> $CONFIG
  echo "mainmenu.pos=$(sed "2q;d" $TEMPFILE)" >> $CONFIG
  echo "bootopt.pos=$(sed "3q;d" $TEMPFILE)" >> $CONFIG
  
  echo -e "\n[800x600]" >> $CONFIG
  # we need to extract these variables from temporary file
  echo "screen.size=$(sed "4q;d" $TEMPFILE)" >> $CONFIG
  echo "mainmenu.pos=$(sed "5q;d" $TEMPFILE)" >> $CONFIG
  echo "bootopt.pos=$(sed "6q;d" $TEMPFILE)" >> $CONFIG
  
  echo -e "\n[640x480]" >> $CONFIG
  # we need to extract these variables from temporary file
  echo "screen.size=$(sed "7q;d" $TEMPFILE)" >> $CONFIG
  echo "mainmenu.pos=$(sed "8q;d" $TEMPFILE)" >> $CONFIG
  echo "bootopt.pos=$(sed "9q;d" $TEMPFILE)" >> $CONFIG  
  
  # Replace the original
  mv "$CONFIG" "$GFXBOOT"
}
export -f save_settings

# =============================================================================
export WINNAME="Get Position"

# Later - put a path to currently chosen picture in PICTURE=
##PICTURE="`ls -R /usr/share/backgrounds/* | head -1`" 
PICTURE="$dir/original-message-file/back.jpg" 

get_xy () { 
  read MX MY WX WY <<< `getcurpos && xwininfo -name "$WINNAME" 2>/dev/null | awk 'NR>=4&&NR<=5 {print $4}'` 
  X=$(( ($MX-$WX)-8))
  Y=$(($MY-$WY-8))

  [ $X -lt 0 ] && X=0
  [ $Y -lt 0 ] && Y=0
  
  echo "X:$X   Y:$Y"
}
export -f get_xy

store_xy () {
  get_xy
  LINE_NR=$(</tmp/tempfile_index)
  sed -i "${LINE_NR}c$X,$Y" $TEMPFILE
}
export -f store_xy

### Determines Layout which Layout buttons to deactivate
if [ $LAYOUT = 1024x768 ]; then
show1024=true
show800=false
show640=false
elif [ $LAYOUT = 800x600 ]; then
show1024=false
show800=true
show640=false
elif [ $LAYOUT = 640x480 ]; then
show1024=false
show800=false
show640=true
fi

### This is the about dialog ##################################################
export ABOUT='
<window window-position="2" icon-name="gtk-edit" title="BSME-2.0">
<frame>
<vbox>
<text space-fill="true"><label>"Boot-Splash Message Editor
              Version 2.0"
</label></text>
<pixmap>
<input file>about.png</input>
<variable>ABOUT</variable>
</pixmap>
<text><label>"Written by: smokey01
     CatDude and SFR"</label></text>
<button ok>
<action>closewindow:ABOUT</action>
</button>
</vbox>
</frame>
</window>'

###############################################################################

# BTW, I used <button> instead of <eventbox> so it's compatibile with Gtkdalog >= 0.8.0 now

INTERVAL=250			# in milliseconds, if CPU usage is to high, increase this value

export GET_POSITION_1024x768='
<window window-position="3" title="'$WINNAME'" modal="true" resizable="false">
  <vbox>
    <button relief="2">
      <width>1024</width>
      <height>768</height>
      <input file>"'$PICTURE'"</input>
      <action signal="button-press-event">store_xy</action>
      <variable>varGET_POSITION</variable>
      <action type="closewindow">varGET_POSITION</action>
    </button>
    <statusbar has-resize-grip="false">
      <variable>COORDS</variable>
      <input>get_xy</input>
    </statusbar>
    <timer milliseconds="true" interval="'$INTERVAL'" visible="false">
      <action>refresh:COORDS</action>
    </timer>
  </vbox>
</window>'

export GET_POSITION_800x600='
<window window-position="3" title="'$WINNAME'" modal="true" resizable="false">
  <vbox>
    <button relief="2">
      <width>800</width>
      <height>600</height>
      <input file>"'$PICTURE'"</input>
      <action signal="button-press-event">store_xy</action>
      <variable>varGET_POSITION</variable>
      <action type="closewindow">varGET_POSITION</action>
    </button>
    <statusbar has-resize-grip="false">
      <variable>COORDS</variable>
      <input>get_xy</input>
    </statusbar>
    <timer milliseconds="true" interval="'$INTERVAL'" visible="false">
      <action>refresh:COORDS</action>
    </timer>
  </vbox>
</window>'

export GET_POSITION_640x480='
<window window-position="3" title="'$WINNAME'" modal="true" resizable="false">
  <vbox>
    <button relief="2">
      <width>640</width>
      <height>480</height>
      <input file>"'$PICTURE'"</input>
      <action signal="button-press-event">store_xy</action>
      <variable>varGET_POSITION</variable>
      <action type="closewindow">varGET_POSITION</action>
    </button>
    <statusbar has-resize-grip="false">
      <variable>COORDS</variable>
      <input>get_xy</input>
    </statusbar>
    <timer milliseconds="true" interval="'$INTERVAL'" visible="false">
      <action>refresh:COORDS</action>
    </timer>
  </vbox>
</window>'

# =============================================================================

export SCREEN_1024x768='
<window icon-name="gtk-edit" window-position="3" title="1024x768" modal="true">
  <vbox>
    <hbox>
      <text xalign="0"><label>Image size:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" back.jpg must be this size " sensitive="false" space-fill="false" space-expand="false">
        <variable>varSCREEN_SIZE_1024x768</variable>
        <input>sed "1q;d" $TEMPFILE</input>
        <action>sed -i "1c$varSCREEN_SIZE_1024x768" $TEMPFILE</action>
      </entry>
     </hbox>
    <hbox>
      <text xalign="0"><label>Main menu position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. " sensitive="true" space-fill="false" space-expand="false">
        <variable>varMAINMENU_POS_1024x768</variable>
        <input>sed "2q;d" $TEMPFILE</input>
        <action>sed -i "2c$varMAINMENU_POS_1024x768" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Select menu position ">
        <input file stock="gtk-select-color"></input>
        <action>echo 2 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_1024x768</action>
        <action signal="focus-in-event">refresh:varMAINMENU_POS_1024x768</action>
      </button>
     </hbox>
    <hbox>
      <text xalign="0"><label>Boot options position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. " sensitive="true" space-fill="false" space-expand="false">
        <variable>varBOOTOPT_POS_1024x768</variable>
        <input>sed "3q;d" $TEMPFILE</input>
        <action>sed -i "3c$varBOOTOPT_POS_1024x768" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Position of Boot Options text.
 X coordinate MUST be at least 112 
 or the text will not display. ">
        <input file stock="gtk-select-color"></input>
        <action>echo 3 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_1024x768</action>
        <action signal="focus-in-event">refresh:varBOOTOPT_POS_1024x768</action>
      </button>
     </hbox>
     <button ok>
       <variable>varSCR</variable>
       <action type="closewindow">varSCR</action>
     </button>
  </vbox>
</window>'

# -----------------------------------------------------------------------------
export SCREEN_800x600='
<window icon-name="gtk-edit" window-position="3" title="800x600" modal="true">
  <vbox>
    <hbox>
      <text xalign="0"><label>Image size:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" back.jpg must be this size " sensitive="false" space-fill="false" space-expand="false">
        <variable>varSCREEN_SIZE_800x600</variable>
        <input>sed "4q;d" $TEMPFILE</input>
        <action>sed -i "4c$varSCREEN_SIZE_800x600" $TEMPFILE</action>
      </entry>
     </hbox>
    <hbox>
      <text xalign="0"><label>Main menu position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. "space-fill="false" space-expand="false">
        <variable>varMAINMENU_POS_800x600</variable>
        <input>sed "5q;d" $TEMPFILE</input>
		<action>sed -i "5c$varMAINMENU_POS_800x600" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Select menu position ">
        <input file stock="gtk-select-color"></input>
        <action>echo 5 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_800x600</action>
        <action signal="focus-in-event">refresh:varMAINMENU_POS_800x600</action>
      </button>
     </hbox>
    <hbox>
      <text xalign="0"><label>Boot options position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. " space-fill="false" space-expand="false">
        <variable>varBOOTOPT_POS_800x600</variable>
        <input>sed "6q;d" $TEMPFILE</input>
        <action>sed -i "6c$varBOOTOPT_POS_800x600" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Position of Boot Options text.
 X coordinate MUST be at least 112 
 or the text will not display. ">
        <input file stock="gtk-select-color"></input>
        <action>echo 6 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_800x600</action>
        <action signal="focus-in-event">refresh:varBOOTOPT_POS_800x600</action>
      </button>
     </hbox>
     <button ok>
       <variable>varSCR</variable>
       <action type="closewindow">varSCR</action>
     </button>
  </vbox>
</window>'

# -----------------------------------------------------------------------------
export SCREEN_640x480='
<window icon-name="gtk-edit" window-position="3" title="640x480" modal="true">
  <vbox>
    <hbox>
      <text xalign="0"><label>Image size:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" back.jpg must be this size " sensitive="false" space-fill="false" space-expand="false">
        <variable>varSCREEN_SIZE_640x480</variable>
        <input>sed "7q;d" $TEMPFILE</input>
        <action>sed -i "7c$varSCREEN_SIZE_800x600" $TEMPFILE</action>
      </entry>
     </hbox>
    <hbox>
      <text xalign="0"><label>Main menu position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. "space-fill="false" space-expand="false">
        <variable>varMAINMENU_POS_640x480</variable>
        <input>sed "8q;d" $TEMPFILE</input>
        <action>sed -i "8c$varMAINMENU_POS_640x480" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Select menu position ">
        <input file stock="gtk-select-color"></input>
        <action>echo 8 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_640x480</action>
        <action signal="focus-in-event">refresh:varMAINMENU_POS_640x480</action>
      </button>
     </hbox>
    <hbox>
      <text xalign="0"><label>Boot options position:</label></text>
      <text space-fill="true" space-expand="true"><label>" "</label></text>
      <entry tooltip-text=" Enter coordinates or click the button on the  right to select a position on the image. " space-fill="false" space-expand="false">
        <variable>varBOOTOPT_POS_640x480</variable>
        <input>sed "9q;d" $TEMPFILE</input>
        <action>sed -i "9c$varBOOTOPT_POS_640x480" $TEMPFILE</action>
      </entry>
      <button tooltip-text=" Position of Boot Options text.
 X coordinate MUST be at least 112 
 or the text will not display. ">
        <input file stock="gtk-select-color"></input>
        <action>echo 9 > /tmp/tempfile_index</action>
        <action type="launch">GET_POSITION_640x480</action>
        <action signal="focus-in-event">refresh:varBOOTOPT_POS_640x480</action>
      </button>
     </hbox>
     <button ok>
       <variable>varSCR</variable>
       <action type="closewindow">varSCR</action>
     </button>
  </vbox>
</window>'

# -----------------------------------------------------------------------------

# Beginning of the Main GUI
export MAIN='
<window icon-name="gtk-edit" window-position="1" title="Boot-Splash Editor" resizable="false">
  <vbox space-expand="false" space-fill="false">
  <menubar>
				<menu label="_File" use-underline="true">
								
				<menuitem tooltip-text=" Unpacks the message file " stock-id="gtk-go-up" label="Unpack">
					<variable>uunpack</variable>
					<action>unpack</action>
				</menuitem>
				
				<menuitem tooltip-text=" Builds the message file " stock-id="gtk-go-down" label="Re-Pack">
					<variable>rrepack</variable>
					<action>repack</action>
				</menuitem>
				
				<menuitem tooltip-text=" Opens the working directory " stock-id="gtk-open" label="Open">
					<action>rox $dir/original-message-file</action>
				</menuitem>
				
				<menuitem tooltip-text=" Quits Message Editor " stock-id="gtk-quit" accel-key="0x51" accel-mods="4">
					<variable>mniExample</variable>
					<action>exit:Quit</action>
				</menuitem>
							
				</menu>
			
			<menu label="_View" use-underline="true">
				<menuitem tooltip-text=" Displays the Font Settings " checkbox="false" label="Font Converter & Settings">
					<action>if true show:fraFont</action>
					<action>if false hide:fraFont</action>
				</menuitem>
				<menuitem tooltip-text=" Displays the Help Menu colour tools " checkbox="false" label="Help Menu Colours">
					<action>if true show:fraHelp</action>
					<action>if false hide:fraHelp</action>
				</menuitem>
				<menuitem tooltip-text=" Displays the Image file "checkbox="false" label="Background Image">
					<action>if true show:fraImage</action>
					<action>if false hide:fraImage</action>
				</menuitem>
				<variable>varBACKGROUND</variable>
			</menu>
			
			<menu label="_Help" use-underline="true">
				<menuitem tooltip-text=" Basic local Help " stock-id="gtk-help">
					<variable>mniExample</variable>
					<action>defaulttexteditor help.txt</action>
				</menuitem>
				
				<menuitem tooltip-text=" Detailed online Help " stock-id="gtk-info">
					<variable>mniExample</variable>
					<action>defaultbrowser http://www.smokey01.com/help/bsme/</action>
				</menuitem>
				
				<menuitem tooltip-text=" The authors " stock-id="gtk-about">
					<action type="launch">ABOUT</action>
				</menuitem>
				
			</menu>
			<variable>mnbExample</variable>
		</menubar>
		
    <frame Click on the '"$LAYOUT"' Button>
      
   
      <hbox  homogeneous="true">
        <button sensitive="'"$show1024"'" tooltip-text=" Select the Menu and Boot Option
 positions for the 1024x768 image. " space-fill="true">
          <label>1024x768</label>
          <action type="launch">SCREEN_1024x768</action>
        </button>
        <button sensitive="'"$show800"'" tooltip-text=" Select the Menu and Boot Option
 positions for the 800x600 image. " space-fill="true">
          <label>800x600</label>
          <action type="launch">SCREEN_800x600</action>
        </button>
        <button sensitive="'"$show640"'" tooltip-text=" Select the Menu and Boot Option
 positions for the 640x480 image. " space-fill="true" visible="true">
          <label>640x480</label>
          <action type="launch">SCREEN_640x480</action>
        </button>

      <entry visible="false">
      <variable>varLAYOUT</variable>
      <default>'"$LAYOUT"'</default>
      </entry>
      </hbox>
    </frame>



      <vbox visible="false">
    <frame Font Converter & Settings >
    <vbox homogeneous="true">
		<hbox>
			<comboboxtext width-request="70" tooltip-text=" Select font size ">
				<default>16</default>
				<variable>FNTSIZE</variable>
				<item>12</item>
				<item>14</item>
				<item>16</item>
				<item>18</item>
				<item>20</item>
				<item>22</item>
				<item>24</item>
				<item>26</item>
				<item>28</item>
				<item>30</item>
			</comboboxtext>
			<entry fs-action="file" fs-folder="/usr/local/bsme/fonts/ttf" fs-filters="*.ttf|*.TTF" fs-title="Select a font" tooltip-text=" Convert a font ">
				<variable>TTF_FONT</variable>
				<input>echo "${TTF_FONT##*/}"</input>
			</entry> 
			<button tooltip-text=" Select a ttf font from the
 following directories only:
 
 /usr/local/bsme/fonts/ttf
 /usr/share/fonts/default/TTF
 /usr/share/fonts/truetype
 /usr/share/fonts/Type1
 /usr/share/fonts/misc
 /usr/X11R6/lib/X11/fonts/truetype 
 /usr/X11R6/lib/X11/fonts/Type1
 /usr/X11R6/lib/X11/fonts/misc 
 
 Then choose your fonts below. ">
				<input file stock="gtk-select-font"></input>
				<action>fileselect:TTF_FONT</action>
				<action>refresh:TTF_FONT</action>
				<action>convertfnt</action>
			</button> 
		</hbox>
    
    <hbox>
      <text xalign="0" width-request="70"><label>Normal:</label></text>
		<entry fs-action="file" fs-folder="/usr/local/bsme/fonts/fnt"
			fs-filters="*.fnt"
			fs-title="Select a font">
			<variable>varFONT_NORMAL</variable>
			<input>echo "${varFONT_NORMAL##*/}"</input>
			<default>'"$FONT_NORMAL"'</default>
		</entry>      
		<button tooltip-text=" This is the font used for
 the F1 Help and Boot Options. ">
			<input file stock="gtk-select-font"></input>
			<action>fileselect:varFONT_NORMAL</action>
			<action>refresh:varFONT_NORMAL</action>
			<action>cp $dir/fonts/fnt/$varFONT_NORMAL $dir/original-message-file/</action>
		</button>
    </hbox>
    <hbox>
      <text xalign="0" width-request="70"><label>Large:</label></text>
		<entry fs-action="file" fs-folder="/usr/local/bsme/fonts/fnt"
			fs-filters="*.fnt"
			fs-title="Select a font">
			<variable>varFONT_LARGE</variable>
			<input>echo "${varFONT_LARGE##*/}"</input>
			<default>'"$FONT_LARGE"'</default>
		</entry>      
		<button tooltip-text=" This is the font used for
 the Main Menu entries. ">
			<input file stock="gtk-select-font"></input>
			<action>fileselect:varFONT_LARGE</action>
			<action>refresh:varFONT_LARGE</action>
			<action>cp $dir/fonts/fnt/$varFONT_LARGE $dir/original-message-file/</action>
		</button>
    </hbox>
    </vbox>
    </frame>
  <variable>fraFont</variable>
  </vbox>
      
<frame Main Menu Settings >
      <hbox homogeneous="true">
       <spinbutton width-request="55" tooltip-text=" Number of visible Menu Entries
 before scrolling is required." range-min="1" range-max="100" range-step="1">
        <variable>varMAINMENU_ENTRIES</variable>
        <default>'"$MAINMENU_ENTRIES"'</default>
      </spinbutton> 
      
      <colorbutton width-request="55" tooltip-text=" Normal text colour ">
          <variable>varMAINMENU_NORMAL_FG</variable>
          <default>'"$MAINMENU_NORMAL_FG"'</default>
        </colorbutton>
        <colorbutton width-request="55" tooltip-text=" Selected text colour ">
          <variable>varMAINMENU_SELECTED_FG</variable>
          <default>'"$MAINMENU_SELECTED_FG"'</default>
        </colorbutton>
      </hbox>

    <hbox homogeneous="true">
      <spinbutton width-request="55" tooltip-text=" Minimum width of the selection bar." range-min="1" range-max="999" range-step="1">
      <variable>varMAINMENU_BAR_MINWIDTH</variable>
      <default>'"$MAINMENU_BAR_MINWIDTH"'</default>
      </spinbutton>
      
      <spinbutton width-request="55" tooltip-text=" Transparency value. Higher
 numbers are more transparent. "range-min="0" range-max="255" range-step="1">
      <variable>varMAINMENU_BAR_TRANSPARENCY</variable>
      <default>'"$MAINMENU_BAR_TRANSPARENCY"'</default>
      </spinbutton>
      
      <colorbutton width-request="55" tooltip-text=" This is the selection bar colour ">
          <variable>varMAINMENU_BAR_COLOR</variable>
          <default>'"$MAINMENU_BAR_COLOR"'</default>
      </colorbutton>
    </hbox>    
    </frame>

<frame F1 Help & Boot Option Settings >
<hbox homogeneous="true">
        <colorbutton tooltip-text=" Text colour of word F1 ">
          <variable>varPANEL_F_KEY_FG</variable>
          <default>'"$PANEL_F_KEY_FG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" Text colour of the word Help ">
          <variable>varPANEL_NORMAL_FG</variable>
          <default>'"$PANEL_NORMAL_FG"'</default>
        </colorbutton>
        
        <colorbutton tooltip-text=" Colour of Boot Options label ">
          <variable>varBOOTOPT_LABEL_FG</variable>
          <default>'"$BOOTOPT_LABEL_FG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" Colour of Boot Options text ">
          <variable>varBOOTOPT_TEXT_FG</variable>
          <default>'"$BOOTOPT_TEXT_FG"'</default>
        </colorbutton>
    </hbox>
</frame>

<vbox visible="false">
<frame Help Menu Colours >
  <vbox>
	<hbox homogeneous="true">
        <colorbutton tooltip-text=" window.bg colour ">
          <variable>varWINDOW_BG</variable>
          <default>'"$WINDOW_BG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" window.fg colour ">
          <variable>varWINDOW_FG</variable>
          <default>'"$WINDOW_FG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" window.title.bg colour ">
          <variable>varWINDOW_TITLE_BG</variable>
          <default>'"$WINDOW_TITLE_BG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" window.title.fg colour ">
          <variable>varWINDOW_TITLE_FG</variable>
          <default>'"$WINDOW_TITLE_FG"'</default>
        </colorbutton>        
        <colorbutton tooltip-text=" window.title.error.bg colour ">
          <variable>varWINDOW_TITLE_ERROR_BG</variable>
          <default>'"$WINDOW_TITLE_ERROR_BG"'</default>
        </colorbutton>
	</hbox>
	<hseparator></hseparator>
	<hbox homogeneous="true">
        <colorbutton tooltip-text=" help.link.fg colour ">
          <variable>varHELP_LINK_FG</variable>
          <default>'"$HELP_LINK_FG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" help.link.selected.fg colour ">
          <variable>varHELP_LINK_SELECTED_FG</variable>
          <default>'"$HELP_LINK_SELECTED_FG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" help.link.selected.bg colour ">
          <variable>varHELP_LINK_SELECTED_BG</variable>
          <default>'"$HELP_LINK_SELECTED_BG"'</default>
        </colorbutton>
        <colorbutton tooltip-text=" help.highlight.fg colour ">
          <variable>varHELP_HIGHTLIGHT_FG</variable>
          <default>'"$HELP_HIGHTLIGHT_FG"'</default>
        </colorbutton>
	</hbox>
  </vbox>
</frame>
<variable>fraHelp</variable>
</vbox>

<vbox visible="false">
<frame Background Image>
    <hbox>
      <button>
       <width>263</width>
       <variable>PIC</variable>
       <input file>'$dir/original-message-file/"$BACKGROUND"'</input>
       <action>now</action>
      </button> 
    <variable>varBACKGROUND</variable>
    <default>'"$BACKGROUND"'</default>  
    </hbox>   
    <hbox homogeneous="true">
    <button> 
		<label>Click to change image.</label>
		<action>Select-Image</action>
		<action>refresh:PIC</action>
    </button> 
    </hbox>   
    </frame>
    <variable>fraImage</variable>
    </vbox>

    
    
    <hbox homogeneous="true">
      <button cancel></button>
      <button>
        <label>Save</label>
        <input file stock="gtk-save"></input>
        <action>save_settings</action>
       </button>
      
      <button>
        <label>Quit</label>
        <input file stock="gtk-quit"></input>
        <action>exit:EXIT</action>
      </button>
      
    </hbox>
  </vbox>
</window>'

###############################################################################
[ `which gtkdialog4` ] && export GTKDIALOG=gtkdialog4 || export GTKDIALOG=gtkdialog
$GTKDIALOG -p MAIN

rm $TEMPFILE
